.. time2relax documentation master file, created by sphinx-quickstart on Mon
   Nov 20 22:39:46 2017.

time2relax: Python CouchDB Driver
=================================

Release v\ |version|.

.. include:: shields.rst
.. include:: pre-1.0.rst

----

API Guide
---------

.. toctree::
   :maxdepth: 2

   interface
